@@ -170,6 +170,76 @@ def quarter_range(yearquarter):
     final_date = datetime(year, final_month, 1)
     return (start_date, final_date)
 
+#################################################################################################
+#################################################################################################
+def generate_yearmonth_monthly(year, month):
+    startmonth = month
+    endmonth = month
+    enddate = calendar.monthrange(year, endmonth)[1]
+
+    yearmonth_start = "{:d}{:02}01".format(year, startmonth)
+    yearmonth_end = "{:d}{:02}{:02}".format(year, month, enddate)
+    yearmonth_timeperiod = str(yearmonth_start) + '-' + str(yearmonth_end)
+
+    return yearmonth_timeperiod
+
+def generate_yearmonth_quaterly(year, month):
+    startmonth = month
+    endmonth = month + 2
+    enddate = calendar.monthrange(year, endmonth)[1]
+
+    yearmonth_start = "{:d}{:02}01".format(year, startmonth)
+    yearmonth_end = "{:d}{:02}{:02}".format(year, endmonth, enddate)
+    yearmonth_timeperiod = str(yearmonth_start) + '-' + str(yearmonth_end)
+
+    return yearmonth_timeperiod
+
+def generate_yearmonth_monthbin(year, month, monthbin):
+    startmonth = month
+    endmonth = month + monthbin
+    enddate = calendar.monthrange(year, endmonth)[1]
+
+    yearmonth_start = "{:d}{:02}01".format(year, startmonth)
+    yearmonth_end = "{:d}{:02}{:02}".format(year, endmonth, enddate)
+    yearmonth_timeperiod = str(yearmonth_start) + '-' + str(yearmonth_end)
+
+    return yearmonth_timeperiod
+
+def generate_quarters_or_yearmonths(year_from, year_till, monthbins = None):
+    q_or_ym = []
+
+    year = int(str(year_from)[:4])
+    month = int(str(year_from)[4:6])
+
+    end_year = int(str(year_till)[:4])
+    end_month = int(str(year_till)[4:6])
+
+
+    while True:
+      if year <=2015:
+         yearmonth = generate_yearmonth_quaterly(year, month)
+         month = month + 3
+      else:
+         if monthbins is None:
+            yearmonth = generate_yearmonth_monthly(year, month)
+            month = month + 1
+         if monthbins is not None:
+             q_or_ym_bins = []
+             for monthbin in monthbins:
+                yearmonth = generate_yearmonth_monthbin(year, month, monthbin-1)
+                q_or_ym_bins.append(yearmonth)
+                month = month + monthbin
+             return q_or_ym_bins
+      q_or_ym.append(yearmonth)
+
+      if year == end_year and month > end_month:
+         break
+
+      if month > 12:
+         year +=1
+         month =1
+    return
+
 #################################################################################################
 #################################################################################################
 def archive_results(tmp_dir_tpl, src_dst_pairs):
